/*
 * @author herbert
 * @date 19.01.2006
 * @version $Id: SamplePlugin.java,v 1.3 2006-01-26 11:09:17 herbert Exp $
 */
package com.gentics.portalnode.sdk.plugin;

import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import com.gentics.api.lib.exception.InsufficientPrivilegesException;
import com.gentics.api.portalnode.plugin.ViewPlugin;
import com.gentics.api.portalnode.templateengine.PrivateKeyException;
import com.gentics.api.portalnode.templateengine.TemplateProcessor;

/**
 * A small SamplePlugin which extends ViewPlugin to add
 * customized behaviour.
 * This example only adds a new Property "samplevalue"
 * to save a value as well as to retrieve the current
 * value of it and the last as "lastsamplevalue"
 * (Used in the example for displaying current view
 * and last active view.)
 * @author herbert
 */
public class SamplePlugin extends ViewPlugin {

	/**
	 * We add ourselves to the context of the template processor so
	 * we can access it from within the velocity context.
	 */
	public TemplateProcessor getTemplateProcessor(RenderRequest renderRequest, RenderResponse renderResponse) {
		TemplateProcessor processor = super.getTemplateProcessor(renderRequest, renderResponse);
		try {
			processor.put("sampleplugin",this);
		} catch (PrivateKeyException e) {
			e.printStackTrace();
		}
		return processor;
	}

	/**
	 * Stores the current value of 'samplevalue'
	 */
	protected String samplevalue;
	/**
	 * Remembers the last value of 'samplevalue'
	 */
	protected String lastsamplevalue;

	/**
	 * This method will be called when someone wants to set the property
	 * 'samplevalue'. First the current value will be saved into 
	 * 'lastsamplevalue' and then store the current value.
	 * 
	 * If a property other than 'samplevalue' should be set we forward
	 * the request to the super class.
	 */
	public boolean setProperty(String property, Object value) throws InsufficientPrivilegesException {
		boolean successSetProperty = super.setProperty(property,value);
		if(property.equals("samplevalue")) {
			this.lastsamplevalue = this.samplevalue;
			this.samplevalue = value.toString();
			return true;
		}
		return successSetProperty;
	}

	/**
	 * Returns the current value of 'samplevalue' or the last value,
	 * called 'lastsamplevalue'
	 * If we don't know of the requested property the super class
	 * will be asked.
	 */
	public Object getProperty(String property) {
		logdebug("getProperty: " + property);
		if(property.equals("samplevalue")) {
			return this.samplevalue;
		}
		if(property.equals("lastsamplevalue")) {
			return this.lastsamplevalue;
		}
		return super.getProperty(property);
	}

}
